struct Application;

impl Application {
    fn new() -> Result<Self, wita::ApiError> {
        wita::Window::builder().title("hello, world!").build()?;
        Ok(Self)
    }
}

impl wita::EventHandler for Application {
    fn closed(&mut self, _: wita::event::Closed) {
        println!("closed");
    }
}

fn main() {
    wita::run(wita::RunType::Wait, Application::new).unwrap();
}
